#!/usr/bin/env node
//noinspection JSUnresolvedFunction,JSUnresolvedVariable
/**
 * Generate xtemplate function by xtemplate file using kissy xtemplate.
 * @author yiminghe@gmail.com
 */
var program = require('./lib/commander');
program
    .option('-p, --package-path <packagePath>', 'Set kissy package path')
    .option('-e, --encoding [encoding]', 'Set xtemplate file encoding', 'utf-8')
    .option('-w, --watch', 'Watch xtemplate file change')
    .option('-k, --kissy', 'kissy module format')
    .parse(process.argv);

var S = require('../build/kissy-nodejs'),
    chokidar = require('chokidar'),
    js_beautify = require('js-beautify').js_beautify,
    fs = require('fs'),
    path = require('path'),
    packagePath = program.packagePath,
    encoding = program.encoding,
    cwd = process.cwd();

packagePath = path.resolve(cwd, packagePath);

var tplTemplate = '' +
    '/*\n' +
    '  Generated by kissy-tpl2mod.' +
    '*/\n' +
    'KISSY.add(\'{code}\');';

function normalizeSlash(str) {
    return str.replace(/\\/g, '/');
}

function my_js_beautify(str) {
    var opts = {"indent_size": "4", "indent_char": " ",
        "preserve_newlines": true, "brace_style": "collapse",
        "keep_array_indentation": false, "space_after_anon_function": true};
    return js_beautify(str, opts);
}

S.use('xtemplate/compiler', function (S, XTemplateCompiler) {
    function compile(tpl, modulePath) {
        var tplContent = fs.readFileSync(tpl, encoding);
        var moduleCode = my_js_beautify(XTemplateCompiler.compileToModule(tplContent, program.kissy ? false : []));
        fs.writeFileSync(modulePath, moduleCode, encoding);
        console.info('generate xtpl module: ' + modulePath + ' at ' + (new Date().toLocaleString()));
    }

    function process(filePath) {
        if (S.endsWith(filePath, '.xtpl.html')) {
            var modulePath = filePath.replace(/\.xtpl\.html$/, '-xtpl.js');
            compile(filePath, modulePath);
        } else if (S.endsWith(filePath, '.tpl.html')) {
            modulePath = filePath.replace(/\.tpl\.html$/, '-tpl.js');
            var tplContent = fs.readFileSync(filePath, encoding);
            tplContent = tplContent.replace(/\\/g, "\\")
                .replace(/\r?\n/g, "\\n")
                .replace(/'/g, "\\'");
            var moduleCode = my_js_beautify(S.substitute(tplTemplate, {
                code: tplContent
            }));
            fs.writeFileSync(modulePath, moduleCode, encoding);
            console.info('generate tpl module: ' + modulePath + ' at ' + (new Date().toLocaleString()));
        }
    }

    if (program.watch) {
        var watcher = chokidar.watch(packagePath, {ignored: /^\./, persistent: true});
        watcher.on('add', process).on('change', process);
        watcher.close();
    } else {
        var walk = require('walk');
        //noinspection JSUnresolvedFunction
        var walker = walk.walk(packagePath);
        walker.on("file", function (root, fileStats, next) {
            var filePath = normalizeSlash(root + '/' + fileStats.name);
            process(filePath);
            next();
        });
    }
});